#!/usr/bin/env python

import os
import re
from argparse import ArgumentParser

FILES = ("/var/log/php-fpm/php-slow.log.1", "/var/log/php-fpm/php-slow.log")


def parse_arguments():
    parser = ArgumentParser(description="Analyze php-fpm slow.log")
    parser.add_argument(
        "--cms",
        help="CMS that uses the modules. (magento_1 or magento_2)",
        type=str,
        default="magento_1",
        choices=("magento_1", "magento_2"),
    )
    return parser.parse_args()


def log_reader():
    for filename in [x for x in FILES if os.path.exists(x)]:
        with open(filename) as fh:
            for line in fh:
                yield line


def find_slow_community_modules(loglines, cms="magento_1"):
    newrequest = True
    for line in loglines:
        if "[pool www] pid" in line:
            timestamp = line[1:21]
            newrequest = True

        if newrequest:
            try:
                if cms == "magento_2":
                    vendor, module = re.search(
                        "app/code/(?:local/|community/|)(.+?)/(.+?)/", line
                    ).groups()
                else:
                    vendor, module = re.search(
                        "app/code/(?:local|community)/(.+?)/(.+?)/", line
                    ).groups()
            except AttributeError:
                continue

            modid = vendor + "_" + module
            yield "{} {}".format(timestamp, modid)
            newrequest = False


def main():
    args = parse_arguments()

    for item in find_slow_community_modules(log_reader(), cms=args.cms):
        print(item)


if __name__ == "__main__":
    main()
