import json
from argparse import ArgumentParser

from kamikaze3.common.args import (
    OUTPUT_FORMAT_JSON,
    add_default_args,
)
from kamikaze3.autoscaling.magento2.validate_magento2 import validate_magento2

BASE_DIR = "/data/web/magento2"


def parse_arguments():
    """
    Parse the hypernode-log arguments
    :return obj args: The parsed arguments
    """
    parser = ArgumentParser(
        description="Returns Object Storage configuration validation for Magento ^2 and Shopware ^6 apps."
    )
    add_default_args(parser)
    parser.add_argument(
        "-P",
        "--path",
        default=BASE_DIR,
        required=False,
        help="Specify app path to the project root directory",
    )
    parsed_args = parser.parse_args()
    return parsed_args


def run_validations(output_format: str, path: str = None):
    output = validate_magento2(path)

    if output_format == OUTPUT_FORMAT_JSON:
        return json.dumps(output)
    else:
        messages = "- " + "\n- ".join(output[1])
        return "Status: {}\n{}".format(output[0], messages)


def main():
    args = parse_arguments()
    result = run_validations(args.output_format, args.path)

    print(result)


if __name__ == "__main__":
    main()
