from operator import is_
from kamikaze3.autoscaling.exec_command import exec_command
import json
import logging

logger = logging.getLogger(__name__)


def remote_storage_enabled(output: str) -> tuple:
    """
    Validate if Magento_RemoteStorage module is enabled
    """
    if output == "Magento_RemoteStorage : Module is enabled":
        return True, "Magento_RemoteStorage is enabled"
    return False, "Magento_RemoteStorage is not enabled"


def database_storage_disabled(output: str) -> tuple:
    """
    Validate if remote database storage is disabled
    """
    if output != "1":
        return True, "Database storage is disabled"
    return False, "system/media_storage_configuration/media_database is not disabled"


def remote_storage_configured_correctly(output: str) -> tuple:
    """
    Validate if app/etc/env.php configured for remote storage
    """
    try:
        data = json.loads(output)
    except json.JSONDecodeError:
        return False, "Invalid JSON format in output of app/etc/env.php"

    remote_storage = data.get("remote_storage")

    if not remote_storage:
        return (
            False,
            "'remote_storage' key is missing or misconfigured in app/etc/env.php",
        )

    driver = remote_storage.get("driver", "").lower()
    if driver not in ["aws-s3"]:
        return False, "Only AWS-s3 remote storage drivers are supported"

    config = remote_storage.get("config", {})
    required_fields = ["endpoint", "bucket", "region", "credentials"]

    missing_fields = [field for field in required_fields if not config.get(field)]
    if missing_fields:
        return (
            False,
            f"Missing required fields: {', '.join(missing_fields)} in remote storage configuration",
        )

    return True, "Remote Storage is configured correctly"


def validate_magento2(path: str) -> tuple:
    commands = {
        "bin/magento module:status Magento_RemoteStorage": remote_storage_enabled,
        "bin/magento config:show system/media_storage_configuration/media_database": database_storage_disabled,
        "php -r 'echo json_encode(include \"app/etc/env.php\");'": remote_storage_configured_correctly,
    }
    results = []
    is_valid = True

    for command, method in commands.items():
        output = str(exec_command("cd {} && {}".format(path, command)))
        result = method(output.strip())
        results.append(result[1])
        if not result[0]:
            is_valid = False

    return is_valid, results
