import json
import logging
from argparse import ArgumentParser

from kamikaze3.autoscaling.exec_command import exec_command
from kamikaze3.common.args import (
    OUTPUT_FORMAT_JSON,
    add_default_args,
)
from kamikaze3.autoscaling.varnish.validate_acl import validate_acl
from kamikaze3.autoscaling.varnish.validate_status import validate_status

logger = logging.getLogger(__name__)


def parse_arguments():
    """
    Parse the hypernode-log arguments
    :return obj args: The parsed arguments
    """
    parser = ArgumentParser(
        description="Returns Varnish configuration and health check information"
    )
    add_default_args(parser)
    parsed_args = parser.parse_args()
    return parsed_args


def run_validations(output_format):
    commands = {
        "status": exec_command("varnishadm status"),
        "ping": exec_command("varnishadm ping"),
        "backend_list": exec_command("varnishadm backend.list"),
        "vcl_list": exec_command("varnishadm vcl.list"),
        "purge_acl": exec_command("varnishadm vcl.show"),
    }

    status = validate_status(
        str(commands["status"]),
        str(commands["ping"]),
        str(commands["backend_list"]),
        str(commands["vcl_list"]),
    )
    purge_acl = validate_acl(str(commands["purge_acl"]))

    output = [
        (status[0] and purge_acl[0]),  # is_valid
        status[1] + purge_acl[1],  # merge messages
    ]
    if output_format == OUTPUT_FORMAT_JSON:
        return json.dumps(output)
    else:
        messages = "- " + "\n- ".join(output[1])
        return "Status: {}\n{}".format(output[0], messages)


def main():
    args = parse_arguments()

    result = run_validations(args.output_format)

    print(result)


if __name__ == "__main__":
    main()
