import argparse
import json
from typing import List, Optional

from prettytable import PrettyTable

from kamikaze3.cluster.utils import CLUSTER_FILE, get_cluster_node_info


def pprint_cluster(cluster: dict) -> str:
    pretty_headers = [
        "Hypernode",
        "Roles",
        "Private_IP",
        "Private_subnet",
        "Cluster_IP",
    ]
    cluster_table = PrettyTable(pretty_headers)
    cluster_table.align = "l"
    sorted_cluster_app_names = sorted(
        [node_info["name"] for node_info in cluster["nodes"]]
    )
    for app_name in sorted_cluster_app_names:
        node_info = get_cluster_node_info(cluster, app_name)
        private_network = node_info["network"]
        cluster_table.add_row(
            [
                app_name,
                ", ".join(node_info["roles"]),
                private_network["private_ip"],
                private_network["subnet"],
                node_info["cluster_ip"],
            ]
        )
    print(cluster_table)


def parse_args(args: Optional[List[str]] = None) -> argparse.Namespace:
    parser = argparse.ArgumentParser(
        description="Show the cluster map of the current app"
    )
    return parser.parse_args(args)


def main(initial_args: Optional[List[str]] = None):
    parse_args(initial_args)
    with open(CLUSTER_FILE, "r") as fp:
        cluster = json.load(fp)
    pprint_cluster(cluster)


if __name__ == "__main__":
    main()
