#!/usr/bin/env python3

import argparse
import json
from typing import List, Optional

from kamikaze3.cluster.utils import CLUSTER_FILE, format_node, format_type, get_relation


def render_map(relations: list) -> str:
    cluster_map = ""
    mysql_relation = get_relation(relations, "mysql")
    if mysql_relation:
        child = mysql_relation["child"]
        mysql_parent = mysql_relation["parent"]
        cluster_map += f".-{''.join(['-' for _ in range(len(child))])}-.\n"
        cluster_map += f"| {format_node(child)} |\n"
        cluster_map += f"'-{''.join(['-' for _ in range(len(child))])}-'\n"
        cluster_map += f"  |\n"
        cluster_map += f"  | {format_type(mysql_relation['relation_type'])}\n"
        cluster_map += f"  v\n"
        failover_relation = get_relation(relations, "mysqlfailover")
        if failover_relation:
            failover_child = failover_relation["child"]
            failover_parent = failover_relation["parent"]
            cluster_map += f".-{''.join(['-' for _ in range(len(failover_child))])}-.  {''.join([' ' for _ in range(len(failover_relation['relation_type']))])}   .-{''.join(['-' for _ in range(len(failover_parent))])}-.\n"
            cluster_map += f"| {format_node(failover_relation['child'])} |--{format_type(failover_relation['relation_type'])}-->| {format_node(failover_relation['parent'])} |\n"
            cluster_map += f"'-{''.join(['-' for _ in range(len(failover_child))])}-'  {''.join([' ' for _ in range(len(failover_relation['relation_type']))])}   '-{''.join(['-' for _ in range(len(failover_parent))])}-'\n"
        else:
            cluster_map += f".-{''.join(['-' for _ in range(len(mysql_parent))])}-.\n"
            cluster_map += f"| {format_node(mysql_parent)} |\n"
            cluster_map += f"'-{''.join(['-' for _ in range(len(mysql_parent))])}-'\n"
    return cluster_map


def parse_args(args: Optional[List[str]] = None) -> argparse.Namespace:
    parser = argparse.ArgumentParser(
        description="Show the cluster map of the current app"
    )
    return parser.parse_args(args)


def main(initial_args: Optional[List[str]] = None):
    parse_args(initial_args)
    with open(CLUSTER_FILE, "r") as fp:
        cluster = json.load(fp)
    relations = cluster["relations"]
    cluster_map = render_map(relations)
    print(cluster_map.strip())


if __name__ == "__main__":
    main()
