import json
from typing import Optional

from colorama import Fore

from kamikaze3.common.env import get_app_name

CLUSTER_FILE = "/etc/hypernode/nodes.json"


def format_node(node: str) -> str:
    if node == get_app_name():
        return Fore.RED + node + Fore.RESET
    else:
        return node


def format_type(relation_type: str) -> str:
    return Fore.CYAN + relation_type + Fore.RESET


def get_relation(relations: list, relation_type: str) -> Optional[dict]:
    for relation in relations:
        if relation["relation_type"] == relation_type:
            return relation


def get_cluster_node_info(cluster: dict, app_name: str) -> dict:
    for node_info in cluster["nodes"]:
        if node_info["name"] == app_name:
            return node_info
    raise RuntimeError(f"Could not find node info for {app_name}")


def is_part_of_cluster() -> bool:
    try:
        with open(CLUSTER_FILE) as f:
            cluster = json.load(f)
    except FileNotFoundError:
        return False
    return len(cluster["nodes"]) > 1
