import logging
from time import sleep

logger = logging.getLogger(__name__)


def retry_on_exception(max_retries=0, wait_time=0):
    """
    This decorator will retry a function when it raises an exception.
    After #max_retries tries it will re-raise the last exception.
    If a retry is successful, the original return value is returned.
    Decorator-credits for Rik for conceiving this! --WdG

    :param int max_retries: Amount of retry attempts before giving up
    :param int wait_time: Amount of seconds to wait between attempts
    """

    def decorator(function):
        def wrapper(*f_args, **f_kwargs):
            counter = 0
            while counter <= max_retries:
                counter += 1
                try:
                    return function(*f_args, **f_kwargs)
                except Exception as e:
                    logger.warning(
                        "Caught exception {error_type} '{error}' of while running '{function}'!".format(
                            error_type=type(e), error=e, function=function
                        )
                    )
                    if counter <= max_retries:
                        logger.warning(
                            "Retrying! (Attempt {} of {})".format(counter, max_retries)
                        )
                        sleep(wait_time)
                    else:
                        logger.warning(
                            "Still failing after {} runs. Propagating exception.".format(
                                counter
                            )
                        )
                        raise

        return wrapper

    return decorator
