import subprocess
from typing import Tuple

from kamikaze3.common.settings import FPM_BIND_ADDRESS


def run_fpm_script(
    script: str,
    request_method: str = "GET",
    fpm_address: Tuple[str, int] = FPM_BIND_ADDRESS,
) -> str:
    """
    Run a PHP script with PHP-FPM without NGINX
    """
    output = subprocess.check_output(
        ["/usr/bin/cgi-fcgi", "-bind", "-connect", "{}:{}".format(*fpm_address)],
        env={
            "REQUEST_METHOD": request_method,
            "SCRIPT_FILENAME": script,
        },
        encoding="utf-8",
    )

    # The output also contains headers followed by an empty line to separate the mark the end of the headers section.
    # So we strip those lines out.
    response_body = output.split("\n\n", 1)[1]

    return "".join(response_body)
