import subprocess

ALGO_MD5 = "md5"
ALGO_SHA256 = "sha256"
ALGO_SHA512 = "sha512"

OPENSSL_ALGO_MAP = {
    ALGO_MD5: "-1",
    ALGO_SHA256: "-5",
    ALGO_SHA512: "-6",
}


def get_password_hash(password: str, algo: str = ALGO_SHA512) -> str:
    if algo not in OPENSSL_ALGO_MAP:
        raise ValueError("Unsupported hashing algorithm: {}".format(algo))

    return (
        subprocess.check_output(
            ["/usr/bin/openssl", "passwd", OPENSSL_ALGO_MAP[algo], "-stdin"],
            input=password.encode(),
        )
        .decode()
        .strip()
    )
