import socket
from collections import namedtuple
from platform import system
from types import SimpleNamespace
from typing import List, Optional

if system() == "Darwin":
    Connections = SimpleNamespace()
    _connections = Connections
else:
    from psutil._pslinux import Connections

    _connections = Connections()
    _connections._procfs_path = "/proc"  # pyright: ignore

# pconn is also in psutil._common, but because of abstraction,
# it leaves out the "pid" field, which we need.
pconn_tcp = namedtuple(
    "pconn", ["fd", "family", "type", "laddr", "raddr", "status", "pid"]
)


def get_inodes():
    inodes = _connections.get_all_inodes()
    if not inodes:
        # no connections for this process
        return []
    return inodes


def get_tcp_connections() -> List[pconn_tcp]:
    ret = list()
    connections: Optional[List[pconn_tcp]] = list(
        Connections.process_inet(
            "/proc/net/tcp",
            socket.AF_INET,
            socket.SOCK_STREAM,
            get_inodes(),
        )
        or []
    )
    for fd, family, type_, laddr, raddr, status, pid in connections:
        conn = pconn_tcp(fd, family, type_, laddr, raddr, status, pid)
        ret.append(conn)

    return ret
