import logging

from kamikaze3.cluster.utils import is_part_of_cluster
from kamikaze3.common.api import HttpApiClient
from kamikaze3.common.env import get_app_name
from kamikaze3.dbus.interfaces.nginx_config_reloader import NGINX_CONFIG_RELOADER
from kamikaze3.dbus_event_listener.settings import PROGRAM_NAME
from kamikaze3.event_listener.settings import EVENT_RELOAD_NGINX

logger = logging.getLogger(PROGRAM_NAME)

APP_NATS_API_ENDPOINT = "v2/nats/{}/{}"


def handle_reload_event():
    if is_part_of_cluster():
        logger.info(f"Propagating nginx reload event to cluster")
        url = APP_NATS_API_ENDPOINT.format(get_app_name(), EVENT_RELOAD_NGINX)
        api_client = HttpApiClient()
        api_client.post(url, params={"propagate_to_cluster": True})


def setup_nginx_config_reloader_listener():
    nginx_config_reloader_proxy = NGINX_CONFIG_RELOADER.get_proxy()
    nginx_config_reloader_proxy.ConfigReloaded.connect(handle_reload_event)
