import argparse
from logging import getLogger
from typing import List, Optional

from dasbus.loop import EventLoop

from kamikaze3.common.log import setup_logging
from kamikaze3.dbus_event_listener.events.nginx_config_reloader import (
    setup_nginx_config_reloader_listener,
)
from kamikaze3.dbus_event_listener.settings import PROGRAM_NAME

logger = getLogger(PROGRAM_NAME)

EVENT_LISTENERS = [
    setup_nginx_config_reloader_listener,
]


def setup_event_listeners():
    for setup_callback in EVENT_LISTENERS:
        setup_callback()


def run():
    loop = EventLoop()
    try:
        loop.run()
    finally:
        loop.quit()


def parse_args(args: Optional[List[str]] = None) -> argparse.Namespace:
    parser = argparse.ArgumentParser(
        description="Start the Hypernode D-Bus event listener"
    )
    parser.add_argument(
        "-v",
        "--verbose",
        help="Enable verbose logging",
        action="store_true",
        default=False,
    )
    return parser.parse_args(args)


def main(args: Optional[List[str]] = None):
    args = parse_args(args)
    setup_logging(logger, args.verbose)

    setup_event_listeners()
    run()
