import logging
import subprocess
from datetime import datetime

from kamikaze3.event_listener.settings import PROGRAM_NAME

logger = logging.getLogger(PROGRAM_NAME)


def get_default_nats_server() -> str:
    # NATS server is defined in /etc/defaults/hypernode-event-listener
    try:
        with open("/etc/default/hypernode-event-listener") as f:
            for line in f.readlines():
                if line.startswith("HYPERNODE_NATS_SERVER="):
                    return line.split("=")[1].strip()
    except FileNotFoundError:
        pass
    log(f"Couldn't find NATS_SERVER, assuming localhost")
    return "nats://localhost:4222"


def get_default_nats_ssl_context() -> dict:
    # NATS SSL context is defined in /etc/defaults/hypernode-event-listener
    try:
        ssl_context = {}
        with open("/etc/default/hypernode-event-listener") as f:
            for line in f.readlines():
                if line.startswith("HYPERNODE_NATS_CERT="):
                    ssl_context["crt"] = line.split("=")[1].strip()
                elif line.startswith("HYPERNODE_NATS_KEY="):
                    ssl_context["key"] = line.split("=")[1].strip()
                elif line.startswith("HYPERNODE_NATS_CA="):
                    ssl_context["ca"] = line.split("=")[1].strip()
        return ssl_context
    except FileNotFoundError:
        pass
    logger.warning(f"Couldn't find NATS_SSL_CONTEXT, assuming no SSL")
    return {}


def is_event_listener_active() -> bool:
    try:
        subprocess.check_call(["systemctl", "is-active", "hypernode-event-listener"])
    except subprocess.CalledProcessError:
        return False
    return True


# Separate logging function because this runs in a separate process
def log(msg: str):
    print(f"[kamikaze3-event-listener] {datetime.now().isoformat()} {msg}")
