from os import path
import json

CLUSTER_NODES_FILE = "/etc/hypernode/nodes.json"
HYPERNODE_APP_CONFIG = "/etc/hypernode/app.json"


def get_app_names_by_role(args):
    """
    Get list of cluster apps with given role
    :param str role: name of the role
    :return list[dict, ...]: a list of node names
    """
    result = []
    if not path.exists(CLUSTER_NODES_FILE):
        return result

    with open(CLUSTER_NODES_FILE, "r") as f:
        data = json.load(f)

    for node in data["nodes"]:
        node_roles = node["roles"]

        for node_role in node_roles:
            if node["name"] in result:
                continue
            if node_role not in args.roles:
                continue

            result.append(node["name"])

    return result


def get_target_app_names(args):
    """
    Get the target app names
    :param obj args: The parsed arguments
    :return list target_app_names: A list of targeted app_names
    """
    target_app_names = get_app_names_by_role(args)

    return target_app_names
