from argparse import ArgumentParser


def parse_arguments(args=None):
    """
    Parse the hypernode-cluster-tail arguments
    :param list args: Optional, defaults to sys.argv
    :return obj args: The parsed arguments
    """

    parser = ArgumentParser(description="Tail logs on cluster specified by role type.")

    parser.add_argument(
        "--verbose", "-v", help="Display debug output", action="store_true"
    )

    parser.add_argument("file", help="path to log file to tail")

    role_choices = [
        "web",
        "mysql",
        "loadbalancer",
        "rabbitmq",
        "redis",
        "elasticsearch",
        "docker",
    ]

    parser.add_argument(
        "--roles",
        help="Roles of app to tail logs for. Leave empty if you want to tail all roles",
        default=role_choices,
        choices=role_choices,
        required=False,
        nargs="+",
    )

    parser.add_argument(
        "-n",
        "--lines",
        type=int,
        default=10,
        help="Number of lines to start tailing with",
    )

    parser.add_argument(
        "-f",
        "--follow",
        action="store_true",
        help="Keep following the logs",
    )

    return parser.parse_args(args)
