from operator import attrgetter

from pytz import timezone

from kamikaze3.common.slack import send_slack_message
from kamikaze3.utils import get_app_name, parse_short_handle_from_host_name


def print_available_backups_for_database(backups, database):
    backup_datetime_file_tuples = format_backups(backups)

    print("Available backups for database: {}".format(database))
    print()
    print("           Date (CET)                  Filename")
    for backup in backup_datetime_file_tuples:
        print(" %20s %40s" % (backup[0], backup[1]))
    print()


def format_backups(backups):
    """
    Sorts the :backups: list by datetime, converts the datetime from UTC to CET,
    and then converts the datetime to string representation

    :param list(MysqlBackup) backups: a list of MysqlBackup objects
    :return: a sorted list of MysqlBackup objects
    """
    backups.sort(key=attrgetter("backup_date"))  # sort by time
    result = []

    for backup in backups:
        # convert to CET
        dt = (
            backup.backup_date.replace(tzinfo=timezone("UTC"))
            .astimezone(timezone("Europe/Amsterdam"))
            .strftime("%Y-%m-%d_%H:%M")
        )
        result.append((dt, backup.filename))

    return result


def slack_restore_db_datetimes(restored_backups):
    """
    Slack restore information to #hyperspam

    :param list(MysqlBackup) restored_backups:
                a list of backups which were restored
    """

    message = "App: {}-{} restored the following databases with dates (CET): ".format(
        parse_short_handle_from_host_name(), get_app_name()
    )

    for b in restored_backups:
        message += "{}: {} ".format(
            b.database,
            b.backup_date.replace(tzinfo=timezone("UTC"))  # convert to CET
            .astimezone(timezone("Europe/Amsterdam"))
            .strftime("%Y-%m-%d_%H:%M"),
        )

    send_slack_message(message)
