import logging
import os
import sys
from pathlib import Path

from kamikaze3.mysqlbackuprotator.settings import LOG_FILE

logger = logging.getLogger()
logger.setLevel(logging.INFO)
logger.propagate = False

# File
file_logformat = (
    "%(asctime)s %(name)s %(levelname)s %(filename)s:%(lineno)s: %(message)s"
)
file_formatter = logging.Formatter(file_logformat)

# Stdout Console
stdout_logformat = "%(asctime)s %(name)s %(levelname)s %(message)s"
stdout_formatter = logging.Formatter(stdout_logformat)
stdout_handler = logging.StreamHandler(sys.stdout)
stdout_handler.setLevel(logging.INFO)

# Do not add logging handlers when running in tests
if not os.environ.get("APP_ENV") == "test":
    logger.addHandler(stdout_handler)

    # Assign file handler here, to prevent permission denied errors
    log_file_path = Path("/tmp/" + LOG_FILE)
    os.makedirs(log_file_path.parent, exist_ok=True)
    file_handler = logging.FileHandler(log_file_path)
    file_handler.setFormatter(file_formatter)
    file_handler.setLevel(logging.INFO)
    logger.addHandler(file_handler)


def get_logger(name):
    """
    Simple syntactic helper function
    """
    return logging.getLogger(name)
