import datetime
from re import match, split

from kamikaze3.mysqlbackuprestore.mysql_backup_class import MysqlBackup
from kamikaze3.mysqlbackuprotator.logger import get_logger
from kamikaze3.mysqlbackuprotator.s3_commands import list_files
from kamikaze3.mysqlbackuprotator.settings import DB_BACKUP_REGEX


def parse_backup_filename_to_datetime(filename):
    """
    Parses the backup name to obtain the datetime object

    returns:
        datetime object parsed
    """
    format = "%Y-%m-%d_%H-%M-%S"
    try:
        date_time = split(DB_BACKUP_REGEX, filename)[1]
        result = datetime.datetime.strptime(date_time, format)
    except Exception as e:
        get_logger(__name__).critical(
            "Unable to parse datetime from filename: '{}', '{}'".format(filename, e)
        )
        raise

    return result


def parse_backups_for_database(bucket, database, **kwargs):
    """
    Parses the backup timestamps from s3

    returns:
        a list of MysqlBackup objects containing the following attributes
            str database: str database name
            datetime datetime: backup date,
            str filename: path to file
    :rtype list(MysqlBackup):
    """
    files = list_files(bucket, database, **kwargs)
    result = []

    for f in files:
        if match(DB_BACKUP_REGEX, f):
            result.append(
                MysqlBackup(
                    backup_date=parse_backup_filename_to_datetime(f),
                    filename=f,
                    database=database,
                )
            )

    return result
