import logging
import os
from datetime import datetime
from errno import ENOENT
from pathlib import Path

from dateutil.tz import tzutc

from kamikaze3.common.settings import ONBOARDING_STATE_PATH

logger = logging.getLogger(__name__)


class Check(object):
    recheck = False
    name = None

    def __init__(self):
        self.new_success_time = datetime.utcnow().replace(tzinfo=tzutc())

    def __repr__(self):
        return self.name

    @property
    def path(self):
        return ONBOARDING_STATE_PATH + "/" + self.name

    @property
    def last_success(self):
        try:
            mtime = os.path.getmtime(self.path)
            return datetime.utcfromtimestamp(mtime).replace(tzinfo=tzutc())
        except OSError:
            return None

    def execute(self):
        if not self.is_marked_done() or self.recheck:
            return self.run(), self.new_success_time
        else:
            return None, None

    def run(self):
        raise RuntimeError(
            "Give your check a run() method to make it actually check something"
        )

    def mark_check_done(self):
        logger.debug("Marking service %s as done" % self)
        Path(self.path).touch()

    def is_marked_done(self):
        return os.path.exists(self.path)

    def unmark_check(self):
        logger.debug("Unmarking service %s" % self)
        try:
            os.unlink(self.path)
        except OSError as e:
            if e.errno != ENOENT:
                raise


class ReCheck(Check):
    recheck = True

    def mark_check_done(self, timestamp=None):
        if not self.is_marked_done():
            super(ReCheck, self).mark_check_done()

        timetuple = (timestamp, timestamp) if timestamp is not None else None
        os.utime(self.path, timetuple)
