import logging
from platform import system

from kamikaze3.oom_monitor.strategy import WaitStrategy

if system() != "Darwin":
    import pyinotify  # noqa

logger = logging.getLogger("kamikaze3.oom_monitor")


IN_MODIFY = 0x00000002  # From /usr/include/sys/inotify.h


class CGroupV2WaitStrategy(WaitStrategy):
    def __init__(self, cgroup_slice: str = ""):
        self.last_oom_kill_count = 0
        self.memory_events_path = f"/sys/fs/cgroup/{cgroup_slice}/memory.events"
        wm = pyinotify.WatchManager()
        self.notifier = pyinotify.Notifier(wm)
        wm.add_watch(self.memory_events_path, IN_MODIFY)
        self._detect_oom_kill()

    def _detect_oom_kill(self):
        with open(self.memory_events_path) as f:
            for line in f:
                if line.startswith("oom_kill"):
                    oom_kill_count = int(line.split()[1])
                    if oom_kill_count > self.last_oom_kill_count:
                        self.last_oom_kill_count = oom_kill_count
                        return True
        return False

    def wait(self):
        while True:
            self.notifier.process_events()
            if self.notifier.check_events():
                self.notifier.read_events()
                if self._detect_oom_kill():
                    return

    def close(self):
        self.notifier.stop()
