from jinja2 import Environment, FileSystemLoader

from kamikaze3.common.env import get_app_info, get_node_roles

TEMPLATE_ENVIRONMENT = Environment(
    autoescape=False, loader=FileSystemLoader("/"), trim_blocks=False
)


def get_app_info_for_rendering() -> dict:
    """
    Get app information for rendering purposes
    """
    app_info = get_app_info()
    app_info["roles"] = get_node_roles()
    return app_info


def render_template(template_file: str, config: dict) -> str:
    """
    Render a jinja template by filling in variables from the given config
    :param str template_file: Jinja template filepath
    :param dict config: Configuration used to fill in the template variables
    :rtype: str
    """

    return TEMPLATE_ENVIRONMENT.get_template(template_file).render(
        config, app=get_app_info_for_rendering()
    )
