import json
import os
import time
from logging import getLogger
from typing import Dict

from kamikaze3.common.filesystem import APP_USER_GID, APP_USER_UID
from kamikaze3.status.settings import REPORT_CACHE_FILE, REPORT_CACHE_TTL

logger = getLogger(__name__)


def is_report_cache_available() -> bool:
    if not os.path.exists(REPORT_CACHE_FILE):
        return False

    try:
        stat = os.stat(REPORT_CACHE_FILE)
        age_in_seconds = int(time.time() - stat.st_mtime)
        return age_in_seconds < REPORT_CACHE_TTL
    except Exception:
        return False


def try_get_report_cache() -> Dict[str, bool]:
    if not os.path.exists(REPORT_CACHE_FILE):
        return {}

    try:
        with open(REPORT_CACHE_FILE, mode="r", encoding="utf-8") as f:
            result = json.load(f)
    except Exception as e:
        logger.error("Something went wrong loading report cache: %s", e)
        result = {}

    if not result:
        try:
            os.unlink(REPORT_CACHE_FILE)
        except OSError as e:
            logger.error("Something went wrong removing report cache: %s", e)

    return result or {}


def try_save_report_cache(result: dict) -> None:
    base_dir = os.path.dirname(REPORT_CACHE_FILE)
    if not os.path.exists(base_dir):
        os.makedirs(base_dir)
        os.chown(base_dir, APP_USER_UID, APP_USER_GID)

    try:
        with open(REPORT_CACHE_FILE, mode="w+", encoding="utf-8") as f:
            f.write(json.dumps(result))
    except Exception as e:
        logger.error("Something went wrong saving report cache: %s", e)
