import re
import subprocess


def check_disk_full() -> bool:
    usage = subprocess.check_output(["/usr/bin/df", "-h", "/data/"], encoding="utf-8")
    return _disk_parse_usage(usage)


def check_disk_inodes_full() -> bool:
    usage = subprocess.check_output(["/usr/bin/df", "-i", "/data/"], encoding="utf-8")
    return _disk_parse_usage(usage)


def _disk_parse_usage(usage: str) -> bool:
    """
    Check if the disk usage is greater than or equal to 95%

    Example content:
      Filesystem      Size  Used Avail Use% Mounted on
      /dev/vdb         75G   21G   50G  30% /data
    """
    root_fs_usage = re.split(r"\s+", usage.splitlines()[1])[4]
    root_fs_usage = root_fs_usage.replace("%", "")
    return int(root_fs_usage) >= 95
