import argparse
from dataclasses import dataclass
from typing import List, Optional

from kamikaze3.status.settings import (
    ELASTICSEARCH_HOST,
    ELASTICSEARCH_PORT,
    MYSQL_HOST,
    NFS_PORT,
    RABBITMQ_HOST,
    RABBITMQ_PORT,
    REDIS_HOST,
    VARNISH_HOST,
    VARNISH_PORT,
)


@dataclass
class StatusConfig:
    verbose: bool = False
    local_only: bool = False
    report_cache: bool = False
    mysql_host: str = MYSQL_HOST
    redis_host: str = REDIS_HOST
    varnish_host: str = VARNISH_HOST
    varnish_port: int = VARNISH_PORT
    rabbitmq_host: str = RABBITMQ_HOST
    rabbitmq_port: int = RABBITMQ_PORT
    nfs_port: int = NFS_PORT
    elasticsearch_host: str = ELASTICSEARCH_HOST
    elasticsearch_port: int = ELASTICSEARCH_PORT


def get_parser() -> argparse.ArgumentParser:
    parser = argparse.ArgumentParser(description="Run system status checks")
    parser.add_argument(
        "--verbose",
        "-v",
        action="store_true",
        help="Enable verbose logging",
    )
    parser.add_argument(
        "--local-only",
        action="store_true",
        help="Only run checks for services on localhost",
    )
    parser.add_argument(
        "--report-cache",
        action="store_true",
        help="Enable report caching",
    )
    parser.add_argument(
        "--mysql-host",
        default="mysqlmaster",
        help="MySQL host to check",
    )
    parser.add_argument(
        "--redis-host",
        default="redismaster",
        help="Redis host to check",
    )
    parser.add_argument(
        "--varnish-host",
        default="varnish",
        help="Varnish host to check",
    )
    parser.add_argument(
        "--varnish-port",
        type=int,
        default=VARNISH_PORT,
        help="Varnish port to check",
    )
    parser.add_argument(
        "--rabbitmq-host",
        default=RABBITMQ_HOST,
        help="RabbitMQ host to check",
    )
    parser.add_argument(
        "--rabbitmq-port",
        type=int,
        default=RABBITMQ_PORT,
        help="RabbitMQ port to check",
    )
    parser.add_argument(
        "--nfs-port",
        type=int,
        default=NFS_PORT,
        help="NFS port to check",
    )
    parser.add_argument(
        "--elasticsearch-host",
        default=ELASTICSEARCH_HOST,
        help="Elasticsearch host to check",
    )
    parser.add_argument(
        "--elasticsearch-port",
        type=int,
        default=ELASTICSEARCH_PORT,
        help="Elasticsearch port to check",
    )

    return parser


def parse_args(args: Optional[List[str]] = None) -> StatusConfig:
    args = get_parser().parse_args(args)  # pyright: ignore

    return StatusConfig(
        args.verbose,
        args.local_only,
        args.report_cache,
        args.mysql_host,
        args.redis_host,
        args.varnish_host,
        args.varnish_port,
        args.rabbitmq_host,
        args.rabbitmq_port,
        args.nfs_port,
        args.elasticsearch_host,
        args.elasticsearch_port,
    )
