#!/usr/bin/env python3
import socket
import subprocess
import sys
from argparse import ArgumentParser


def main(args=None):
    args = parse_arguments(args)
    start_netcat(args.host, args.port)


def parse_arguments(args):
    parser = ArgumentParser()
    parser.add_argument("host")
    parser.add_argument("port", type=int)

    return parser.parse_args(args=args)


def start_netcat(host, port):
    if not is_valid_host(host):
        return

    command = ["netcat", host, str(port)]
    proc = subprocess.Popen(
        command, stdout=sys.stdout, stderr=sys.stderr, stdin=sys.stdin
    )
    proc.communicate()


def is_valid_host(host):
    if host in ["127.0.0.1", "::1", "127.0.0.1/8", "::1/128", "localhost"]:
        return False

    try:
        # Try to connect to host as an ipv4 address
        socket.inet_pton(socket.AF_INET, host)
    except OSError:
        try:
            # Try to connect to host via hostname
            socket.gethostbyname(host)
        except OSError:
            return False
    return True
