import logging
import re
import subprocess

from kamikaze3.log.log import configure_logging
from kamikaze3.supervisorctl.parsing import parse_arguments
from kamikaze3.supervisorctl.redis.setup import handle_redis_setup
from kamikaze3.supervisorctl.varnish.setup import handle_varnish_setup

logger = logging.getLogger(__name__)
MEMORY_LIMIT_KB = 16000000


def should_warn_for_memory_limit():
    command = ["/usr/bin/grep", "MemTotal", "/proc/meminfo"]

    raw_output = subprocess.check_output(command, encoding="utf-8")
    output = re.sub("[^0-9]", "", raw_output)

    return int(output) <= MEMORY_LIMIT_KB


def main(args=None):
    if should_warn_for_memory_limit():
        logger.warning(
            "WARNING: This Hypernode is currently on a plan with less than 16 GB memory. "
            "We recommend that you only use hypernode-manage-supervisor "
            "if you are sure you have enough memory available at all times. "
            "If you are not sure, please consider upgrading your plan before using this functionality."
        )

    args = parse_arguments(args=args)
    configure_logging("kamikaze3.supervisorctl", args.verbose)
    if args.service in ["redis", "redis-persistent"]:
        handle_redis_setup(args.application_name, args.service, args.ram)
    elif args.service in ["varnish"]:
        handle_varnish_setup(args.application_name, args.ram)
    else:
        logger.warning(
            "Invalid service detected, please use `$ hypernode-manage-supervisor --help` "
            "to get supported services for this command."
        )
