import logging
import os

from kamikaze3.privileged.manage_vhosts.checksum import (
    ensure_checksum_line,
    get_file_checksum,
)
from kamikaze3.supervisorctl.render import render_template

logger = logging.getLogger(__name__)


def write_config(config, src_template, dst_file, update_checksum=False):
    """
    Render the template to the destination using the given config
    :param dict config: Configuration used to fill in the template variables
    :param str src_template: Jinja template filepath
    :param str dst_file: Target path where the rendered file will be placed
    :param bool update_checksum: Calculate the checksum of the dstfile and write it
    to the dstfile
    :rtype: None
    """
    # Remove a possible .j2 extension from the dst file
    if dst_file.endswith(".j2"):
        dst_file = dst_file[:-3]

    rendered = render_template(src_template, config)
    with open(dst_file, "w+") as fp:
        fp.write(rendered)

    checksum = get_file_checksum(dst_file)
    ensure_checksum_line(dst_file, checksum=checksum)


def ensure_destination_dir_exists(path):
    """
    Ensure destination path exists
    :param string path: destination path that should exist
    :return None:
    """
    if not os.path.exists(path):
        logger.info("Creating directory {}".format(path))
        os.makedirs(path)
