from logging import getLogger
from typing import List

from kamikaze3.log.log import configure_logging
from kamikaze3.onboarding import try_call_event_hook
from kamikaze3.supervisorctl.service import (
    ProcessStatus,
    get_process_statuses,
    is_supervisor_running,
)

logger = getLogger(__name__)


def _format_notification_fatal_processes(processes: List[ProcessStatus]) -> List[str]:
    """Format fatal processes for the notifications"""
    return ["{} - {}".format(ps.name, ps.message) for ps in processes]


def notify_client_of_fatal_processes(fatal_processes: List[ProcessStatus]) -> None:
    for ps in fatal_processes:
        logger.debug(f"Notifying user for {ps.name}")
    formatted_processes = _format_notification_fatal_processes(fatal_processes)
    event = {"supervisor-fatal-processes-detected": formatted_processes}
    logger.debug(
        "Sending mail supervisor fatal processes event: {}".format(formatted_processes)
    )
    try_call_event_hook(event)
    logger.info("Mail supervisor fatal processes event sent")


def main() -> None:
    configure_logging(__name__)
    if not is_supervisor_running():
        logger.info("Supervisor is not enabled, nothing to do here.")
        return

    fatal_processes = list(filter(lambda ps: ps.is_fatal(), get_process_statuses()))
    if fatal_processes:
        notify_client_of_fatal_processes(fatal_processes)
