from argparse import ArgumentParser, ArgumentTypeError

MINIMAL_RAM_AMOUNT = 256


def parse_arguments(args=None):
    """
    Parse the hypernode-managed-supervisor arguments
    :param list args: Optional, defaults to sys.argv
    :return obj args: The parsed arguments
    """

    parser = ArgumentParser(
        description="Run extra processes for your applications using supervisor."
    )

    parser.add_argument(
        "--verbose", "-v", help="Display debug output", action="store_true"
    )

    parser.add_argument(
        "application_name", help="application name to apply the settings to"
    )

    parser.add_argument(
        "--ram",
        type=memory_usage,
        help="Amount of memory to assign to the service",
        required=True,
    )

    parser.add_argument(
        "--service",
        help="Enable hypernode supervisor service",
        default="redis",
        choices=("redis", "redis-persistent", "varnish"),
        required=True,
    )

    return parser.parse_args(args)


def memory_usage(memory):
    memory = int(memory)
    if memory < MINIMAL_RAM_AMOUNT:
        raise ArgumentTypeError("Minimum ram amount is {}".format(MINIMAL_RAM_AMOUNT))
    return memory
