import logging
import time

from kamikaze3.common.systemd import check_service_running, get_service_sub_state
from kamikaze3.log.main import block_until_last_flow_done
from kamikaze3.systemctl.settings import set_attribute

logger = logging.getLogger(__name__)
JOB_POST_WAIT = 10


def ensure_system_service_running(service_name, hypernode_systemctl_setting_name):
    """
    Ensure the requested service is enabled and entered running state
    :param string service_name: Name of the service that should entered running state
    :param string hypernode_systemctl_setting_name: Name of the setting in hypernode-systemctl
    :return None:
    """
    if is_system_service_running(service_name):
        return

    logger.info("Starting {} service..".format(service_name))
    handle_start_system_service(hypernode_systemctl_setting_name)


def is_system_service_running(service_name):
    """
    Check if the requested service is active and has entered running state
    :return bool: True if the requested service running, otherwise False
    """
    if not check_service_running(service_name):
        return False

    sub_state = get_service_sub_state(service_name)
    return "running" in sub_state


def handle_start_system_service(hypernode_systemctl_setting_name):
    """
    Enable the requested system service and wait for the job flow
    :param string hypernode_systemctl_setting_name: Name of the setting in hypernode-systemctl
    :return None:
    """
    set_attribute(hypernode_systemctl_setting_name, "True")

    # Wait a little bit to let the job be posted on the jobboard
    logger.info(
        "Waiting {} seconds until update jobs are posted..".format(JOB_POST_WAIT)
    )
    time.sleep(JOB_POST_WAIT)

    # Wait for update
    block_until_last_flow_done()
