import logging

from kamikaze3.systemctl.alternative_php_versions.manage import (
    ALTERNATIVE_PHP_VERSIONS_EAV,
)
from kamikaze3.systemctl.settings.parsing import get_eav_descriptions

log = logging.getLogger(__name__)


def setup_alternative_php_parsing(sub_parsers):
    php_parser = sub_parsers.add_parser(
        "alternative_php_versions",
        usage="hypernode-systemctl alternative_php_versions enable 8.3",
    )

    php_parser.add_argument("action", choices={"list", "enable", "disable"})
    values_group = php_parser.add_mutually_exclusive_group(required=False)
    values_group.add_argument("positional_value", nargs="?")


def _check_valid_value(parsed_args):
    new_value = parsed_args.positional_value
    allowed_values = get_eav_descriptions(ignore_excluded_eavs=False)[
        ALTERNATIVE_PHP_VERSIONS_EAV
    ]
    if isinstance(allowed_values, list):
        allowed_lowercase_values = [
            v.lower() for v in allowed_values if v.lower() in ["true", "false"]
        ]
        if not (
            new_value in allowed_values or new_value.lower() in allowed_lowercase_values
        ):
            log.error(
                "{} is not an valid php version. Choices are {}.".format(
                    new_value, allowed_values
                )
            )
            exit(1)
