import requests

from kamikaze3.common.api import (
    HYPERNODE_API_URL,
    SYSTEMCTL_USER_AGENT,
    get_user_api_token,
    handle_api_response,
)
from kamikaze3.common.env import get_app_name


def attach_backup(backup_id=None):
    """
    Attach the latest snapshot backup
    :param str|None backup_id: Backup ID to be attached. None assumes the most recent backup
    :return dict response_json: The json response as a dict
    """
    if backup_id:
        attach_url = HYPERNODE_API_URL + "/v2/app/{}/backup/{}/attach/".format(
            get_app_name(), backup_id
        )
    else:
        attach_url = HYPERNODE_API_URL + "/v2/app/{}/backup/attach_latest/".format(
            get_app_name()
        )
    response = requests.post(
        attach_url,
        headers={
            "Authorization": "Token {}".format(get_user_api_token()),
            "User-Agent": SYSTEMCTL_USER_AGENT,
        },
    )
    handle_api_response(
        response,
        success_message="Attach backup job posted, see hypernode-log "
        "(or livelog) for job progress. The backup will "
        "appear in /data/backup/ once attached",
    )
