import logging

from kamikaze3.common.env import get_app_name
from kamikaze3.common.api import (
    handle_api_response,
    HttpApiClient,
)


logger = logging.getLogger(__name__)


HYPERNODE_API_APP_DETAIL_URL = "v2/app/{}/"
HYPERNODE_DOWNSCALE_URL = "v2/app/{}/downscale/"
HYPERNODE_SETTINGS_AUTO_SCALING = "auto_scaling_enabled"


def change_autoscaling(enable_autoscaling=True, downscale_immediately=False):
    """
    Change autoscaling for the current app
    :return dict response_json: The json response as a dict
    """
    client = HttpApiClient()
    response = client.patch(
        HYPERNODE_API_APP_DETAIL_URL.format(get_app_name()),
        data={HYPERNODE_SETTINGS_AUTO_SCALING: enable_autoscaling},
    )

    handle_msg = "Operation was successful and has been processed."
    if enable_autoscaling:
        handle_msg = handle_msg + (
            " Use 'hypernode-systemctl settings autoscale_trigger_load_percentage' and "
            " 'hypernode-systemctl settings autoscale_trigger_load_avg_minutes' to configure the autoscaling thresholds"
        )

    handle_api_response(response, success_message=handle_msg)

    if downscale_immediately:
        downscale_to_baseplan()


def downscale_to_baseplan():
    """
    Downscale to baseplan for the current app
    :return dict response_json: The json response as a dict
    """
    client = HttpApiClient()
    response = client.post(HYPERNODE_DOWNSCALE_URL.format(get_app_name()))

    handle_msg = (
        "Downscale job posted, see hypernode-log (or livelog) for job progress."
    )
    handle_api_response(response, success_message=handle_msg)
