def setup_autoscaling_parsing(sub_parsers):
    autoscaling_parser = sub_parsers.add_parser("autoscaling")
    autoscaling_parser.add_argument(
        "--enable",
        help="Enable autoscaling for this app. After autoscaling is enabled you can use 'hypernode-systemctl settings autoscale_trigger_load_percentage' and 'hypernode-systemctl settings autoscale_trigger_load_avg_minutes' to configure the autoscaling thresholds",
        action="store_true",
    )
    autoscaling_parser.add_argument(
        "--disable",
        help="Disable autoscaling for this app.",
        action="store_true",
    )
    mutex_group = autoscaling_parser.add_mutually_exclusive_group()
    mutex_group.add_argument(
        "--yes",
        help="Downscale back to baseplan immediately when disabling autoscaling",
        action="store_true",
    )
    mutex_group.add_argument(
        "--no",
        help="Do not downscale back to baseplan immediately when disabling autoscaling",
        action="store_true",
    )


def _handle_prompt_input(parsed_args):
    if parsed_args.yes or parsed_args.no:
        return parsed_args

    value = input(
        "Keep in mind that by default you keep your autoscaled plan until it downgrades back to your base "
        "plan after 24h since the autoscale event. Do you want to downscale immediately? You can not use "
        "the plan change functionality for as long as your Hypernode is on an autoscaled plan (yes/no) "
    )
    while value not in ["yes", "no"]:
        value = input("Invalid value, please enter yes or no: ")

    if value == "yes":
        parsed_args.yes = True
    else:
        parsed_args.no = True

    return parsed_args
