import logging

import requests

from kamikaze3.common.api import (
    HYPERNODE_API_URL,
    SYSTEMCTL_USER_AGENT,
    get_hypernode_api_token,
    handle_api_response,
)

log = logging.getLogger(__name__)


def get_block_attack_descriptions():
    response = requests.get(
        HYPERNODE_API_URL + "/v2/app/block_attack_descriptions/",
        headers={
            "Authorization": "Token {}".format(get_hypernode_api_token()),
            "User-Agent": SYSTEMCTL_USER_AGENT,
        },
    )
    handle_api_response(response)
    return response.json()


def setup_block_attack_parsing(sub_parsers):
    block_attack_descriptions = get_block_attack_descriptions()

    settings_usage = (
        "hypernode-systemctl block_attack BlockChinaBruteForce\n\n"
        "The possible values are: \n\n"
        + "\n".join(
            [
                "{: <25}\t{}".format(key, value)
                for key, value in block_attack_descriptions.items()
            ]
        )
    )
    settings_parser = sub_parsers.add_parser("block_attack", usage=settings_usage)
    settings_parser.add_argument(
        "attack_name", choices=block_attack_descriptions.keys()
    )
