from kamikaze3.systemctl.brancher.settings import (
    CLEARABLE_SERVICES,
    DEFAULT_CLEARABLE_SERVICES,
)


def setup_brancher_parsing(sub_parsers):
    brancher_parser = sub_parsers.add_parser("brancher")
    brancher_parser.add_argument(
        "--show-terminated",
        help="Shows terminated Brancher nodes. Does not show active nodes. "
        "Works in combination with hypernode-systemctl brancher --list",
        action="store_true",
    )
    brancher_parser.add_argument(
        "--show-labels",
        help="Shows labels when listing Brancher nodes. "
        "Works in combination with hypernode-systemctl brancher --list",
        action="store_true",
    )
    brancher_parser.add_argument(
        "--machine-readable",
        help="Prints as JSON instead of the regular human readable output."
        "Works in combination with hypernode-systemctl brancher --list",
        action="store_true",
    )
    mutexgroup = brancher_parser.add_mutually_exclusive_group(required=True)
    mutexgroup.add_argument(
        "--create",
        help="Create an Brancher node",
        action="store_true",
    )
    mutexgroup.add_argument(
        "--list",
        help="List the Brancher nodes of this app",
        action="store_true",
    )
    mutexgroup.add_argument(
        "--delete",
        help="Delete an Brancher node by name. Like hypernode-systemctl brancher --delete appname-abcdefghi",
        type=str,
    )
    brancher_parser.add_argument(
        "--label",
        action="append",
        dest="labels",
        help="Add labels to the Brancher instance. Multiple options allowed",
    )
    brancher_parser.add_argument(
        "--clear-services",
        choices=CLEARABLE_SERVICES,
        default=DEFAULT_CLEARABLE_SERVICES,
        nargs="+",
        help="Clear the data for provided service(s) when creating the Brancher instance. "
        "Useful when you don't want to run the production cron or supervisor. "
        "Can also be useful if you want to supply your own anonymized database. Multiple options allowed",
    )
