import requests
from prettytable import PrettyTable

from kamikaze3.common.api import (
    HYPERNODE_API_URL,
    SYSTEMCTL_USER_AGENT,
    get_hypernode_api_token,
    handle_api_response,
)
from kamikaze3.common.env import get_app_name

HYPERNODE_API_APP_XGRADES_LIST_URL = (
    "/v2/app/{}/scheduled_jobs/?job_type__name=xgrade&executed=false"
)


def create_list_xgrades_table(scheduled_xgrades):
    headers = ["ID", "Description", "Scheduled for"]

    table = PrettyTable(headers)
    for scheduled_xgrade in scheduled_xgrades:
        table.add_row(
            [
                scheduled_xgrade["id"],
                scheduled_xgrade["description"],
                scheduled_xgrade["scheduled_at"],
            ]
        )
    print(table.get_string())


def list_xgrades():
    response = requests.get(
        HYPERNODE_API_URL + HYPERNODE_API_APP_XGRADES_LIST_URL.format(get_app_name()),
        headers={
            "Authorization": "Token {}".format(get_hypernode_api_token()),
            "User-Agent": SYSTEMCTL_USER_AGENT,
        },
    )

    if not handle_api_response(response):
        return
    # Results are paginated
    scheduled_xgrades = response.json()["results"]
    create_list_xgrades_table(scheduled_xgrades)
