import logging

import requests

from kamikaze3.common.api import (
    HYPERNODE_API_URL,
    SYSTEMCTL_USER_AGENT,
    get_hypernode_api_token,
    handle_api_response,
)
from kamikaze3.common.env import get_app_name

logger = logging.getLogger(__name__)

PERFORM_PREINSTALL_ENDPOINT = HYPERNODE_API_URL + "/v2/app/{}/perform_preinstall/"


def preinstall(preinstall_type, sample_data=True):
    """
    Send the preform preinstall request to Hypernode API
    :param str preinstall_type: The name of the preinstall type (e.g. magento1, shopware5)
    :param bool sample_data: True if sample data is to be installed (only if available)
    """
    app_name = get_app_name()
    request_url = PERFORM_PREINSTALL_ENDPOINT.format(app_name)
    data = {"preinstall_type": preinstall_type, "sample_data": sample_data}
    headers = {
        "Authorization": "Token {}".format(get_hypernode_api_token()),
        "User-Agent": SYSTEMCTL_USER_AGENT,
    }
    response = requests.post(request_url, data=data, headers=headers)

    message = "Preinstall {}{} job posted, see hypernode-log (or livelog) for job progress.".format(
        preinstall_type, " with sample data" if sample_data else ""
    )
    handle_api_response(response, success_message=message)
