import logging
from time import sleep
import requests

from kamikaze3.common.env import get_app_name, host_is_a_docker
from kamikaze3.common.api import (
    get_hypernode_api_token,
    HYPERNODE_API_URL,
    get_job_from_response,
    handle_api_response,
    SYSTEMCTL_USER_AGENT,
)
from kamikaze3.log.main import block_until_job_is_done


logger = logging.getLogger(__name__)


HYPERNODE_API_APP_DETAIL_URL = HYPERNODE_API_URL + "/v2/app/{}/"
HYPERNODE_AUTOSCALING_LOAD_SETTING = "autoscale_trigger_load_avg_minutes"
HYPERNODE_AUTOSCALING_LOAD_PERCENTAGE_SETTING = "autoscale_trigger_load_percentage"


def set_attribute(attribute, value, block=False):
    if host_is_a_docker():
        logger.info(
            f"Would have set {attribute} to {value}, but we're in a Docker container"
        )
        return

    response = requests.patch(
        HYPERNODE_API_APP_DETAIL_URL.format(get_app_name()),
        headers={
            "Authorization": "Token {}".format(get_hypernode_api_token()),
            "User-Agent": SYSTEMCTL_USER_AGENT,
        },
        data={attribute: value},
    )
    job_id = get_job_from_response(response)
    if job_id and attribute not in [
        HYPERNODE_AUTOSCALING_LOAD_SETTING,
        HYPERNODE_AUTOSCALING_LOAD_PERCENTAGE_SETTING,
    ]:
        handle_msg = (
            "Operation was successful and is being processed. Please allow a few minutes for "
            "the settings to be applied. Run 'livelog' to see the progress."
        )
    elif attribute in [
        HYPERNODE_AUTOSCALING_LOAD_SETTING,
        HYPERNODE_AUTOSCALING_LOAD_PERCENTAGE_SETTING,
    ]:
        handle_msg = "Operation was successful. Changed {} to {}.".format(
            attribute, value
        )
    else:
        handle_msg = (
            "Operation was successful. No job was started because nothing changed."
        )
    handle_api_response(response, handle_msg)
    if block and job_id:
        sleep(1)  # Let the job be picked up
        block_until_job_is_done(job_id)


def get_attribute(attribute):
    response = requests.get(
        HYPERNODE_API_APP_DETAIL_URL.format(get_app_name()),
        headers={
            "Authorization": "Token {}".format(get_hypernode_api_token()),
            "User-Agent": SYSTEMCTL_USER_AGENT,
        },
    )
    handle_api_response(
        response, "{} is set to value {}".format(attribute, response.json()[attribute])
    )
