import logging

import requests

from kamikaze3.common.api import (
    HYPERNODE_API_URL,
    SYSTEMCTL_USER_AGENT,
    get_hypernode_api_token,
    handle_api_response,
)
from kamikaze3.common.env import get_app_name

log = logging.getLogger(__name__)

HYPERNODE_API_WHITELIST_URL = HYPERNODE_API_URL + "/v2/whitelist/{}/"


def add_whitelist_ip(whitelist_type, ip, description=""):
    _handle_whitelist_request(
        "post",
        {"type": whitelist_type, "ip": ip, "description": description},
        'IP {} was successfully added for "{}". Please allow a few '
        "minutes for the settings to be applied.".format(ip, whitelist_type),
    )


def remove_whitelist_ip(whitelist_type, ip):
    _handle_whitelist_request(
        "delete",
        {"type": whitelist_type, "ip": ip},
        'IP {} was successfully removed for "{}". Please allow a few minutes for the '
        "settings to be applied.".format(ip, whitelist_type),
    )


def _handle_whitelist_request(method, data, success_message):
    response = getattr(requests, method)(
        HYPERNODE_API_WHITELIST_URL.format(get_app_name()),
        headers={
            "Authorization": "Token {}".format(get_hypernode_api_token()),
            "User-Agent": SYSTEMCTL_USER_AGENT,
        },
        data=data,
    )
    handle_api_response(response, success_message)


def get_whitelists(whitelist_type=None):
    url = HYPERNODE_API_WHITELIST_URL.format(get_app_name())
    if whitelist_type:
        url += "?type={}".format(whitelist_type)

    response = requests.get(
        url,
        headers={
            "Authorization": "Token {}".format(get_hypernode_api_token()),
            "User-Agent": SYSTEMCTL_USER_AGENT,
        },
    )
    message = "\n".join(
        "Type: {} - IP: {} - Description: {} - Created: {}".format(
            entry["type"], entry["ip"], entry["description"], entry["created"]
        )
        for entry in response.json()
    )
    handle_api_response(
        response, "The following whitelists are set:\n{}".format(message)
    )
