import requests

from kamikaze3.common.api import (
    HYPERNODE_API_URL,
    SYSTEMCTL_USER_AGENT,
    get_hypernode_api_token,
    handle_api_response,
)
from kamikaze3.common.env import get_app_name


def xgrade(product_code, scheduled_at=None):
    """
    XGrade to a different product
    :param str product_code: The code of the product to xgrade to
    :param str scheduled_at: The time at which the xgrade should start
    :return dict response_json: The json response as a dict
    """
    response = requests.patch(
        HYPERNODE_API_URL + "/v2/app/xgrade/{}/".format(get_app_name()),
        data={"product": product_code, "scheduled_at": scheduled_at},
        headers={
            "Authorization": "Token {}".format(get_hypernode_api_token()),
            "User-Agent": SYSTEMCTL_USER_AGENT,
        },
    )

    if scheduled_at:
        success_message = 'XGrade job scheduled, see "hypernode-systemctl list_xgrades" for scheduled xgrades'
    else:
        success_message = (
            "XGrade job posted, see hypernode-log (or livelog) for job progress"
        )

    handle_api_response(response, success_message=success_message)
