import logging
import sys

import requests
from prettytable import PrettyTable

from kamikaze3.common.api import (
    HYPERNODE_API_URL,
    SYSTEMCTL_USER_AGENT,
    get_hypernode_api_token,
    handle_api_response,
)
from kamikaze3.common.env import get_app_name

log = logging.getLogger(__name__)

HYPERNODE_API_APP_PRODUCT_LIST_URL = "/v2/product/app/{}/"


def get_products():
    response = requests.get(
        HYPERNODE_API_URL + HYPERNODE_API_APP_PRODUCT_LIST_URL.format(get_app_name()),
        headers={
            "Authorization": "Token {}".format(get_hypernode_api_token()),
            "User-Agent": SYSTEMCTL_USER_AGENT,
        },
    )
    handle_api_response(response)
    return response.json()


def create_product_table(products):
    headers = ["Product code", "Name", "Price", "CPUs", "RAM", "Disk", "Provider"]

    table = PrettyTable(headers)
    for product in products:
        flavor = product["provider_flavors"][0]

        table.add_row(
            [
                product["code"],
                product["name"],
                "€{}".format(int(round(product["price"] / 100, 0))),
                flavor["vcpus"],
                "{} GB".format(int(round(flavor["ram_in_mb"] / 1024, 0))),
                "{} GB".format(flavor["disk_size_in_gb"]),
                flavor["provider"]["display_name"],
            ]
        )
    return table.get_string()


def setup_xgrade_parsing(sub_parsers):
    settings_usage = "hypernode-systemctl xgrade MAGP32"
    products = []

    if "xgrade" in sys.argv:
        products = get_products()

        settings_usage += "\n\nThe possible products are: \n\n"
        settings_usage += create_product_table(products)

    settings_parser = sub_parsers.add_parser("xgrade", usage=settings_usage)
    settings_parser.add_argument(
        "product_code", choices=[product["code"] for product in products]
    )
    settings_parser.add_argument(
        "--scheduled-at",
        required=False,
        help="When to execute the xgrade (format: 2021-12-30T12:00:00+01:00)",
    )
